==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicInternalFrameUI__24InternalFrameBorder.h <==
// class javax.swing.plaf.basic.BasicInternalFrameUI$InternalFrameBorder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class 62eec9b2dd96ef95 javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder

// header file dependencies
// @dep_header javax_swing_border_AbstractBorder

#include "javax/swing/border/AbstractBorder.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$object	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$object;

typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$fields_struct	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$fields_struct {
	jint	bSize;
	jint	offset;
};
extern _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$fields_struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$method$_init$05643df5b45f5094(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object *);
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$method$_init$504d8b49ccf299e1(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__241$object *);

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$object *, struct _jc_java_awt_Component$object *);
extern jboolean _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$object *);
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$method_info$paintBorder$4a79b2eae89db578;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$object *, struct _jc_java_awt_Component$object *);
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$object *);
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vmethods	javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$sub_refs	javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicInternalFrameUI__24InternalFrameBorder.h <==
// class javax.swing.plaf.basic.BasicInternalFrameUI$InternalFrameBorder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class 62eec9b2dd96ef95 javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder

// header file dependencies
// @dep_header javax_swing_border_AbstractBorder

#include "javax/swing/border/AbstractBorder.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$object	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$object;

typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$fields_struct	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$fields_struct {
	jint	bSize;
	jint	offset;
};
extern _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$fields_struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$method$_init$05643df5b45f5094(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$method$_init$504d8b49ccf299e1(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$method_info$paintBorder$4a79b2eae89db578;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$object *) _JC_JCNI_ATTR;
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vmethods	javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$sub_refs	javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFrameBorder_H_ */
